@@ -329,6 +329,7 @@ def plot_diffeomorphic_map(mapping, ax, delta=15,
     regular grid. The resulting figure contains two images: the direct
     transformation is plotted to the left, and the inverse transformation is
     plotted to the right.
+
     Parameters
     ----------
     mapping : DiffeomorphicMap object
@@ -370,6 +371,7 @@ def plot_diffeomorphic_map(mapping, ax, delta=15,
         if True (default), the deformed grids will be plotted using matplotlib,
         else the grids are just returned
     fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
+
     Returns
     -------
     warped_forward : array
@@ -380,6 +382,7 @@ def plot_diffeomorphic_map(mapping, ax, delta=15,
         Image with the grid showing the effect of transforming the static image to
         the moving image.  Shape will be `inverse_grid_shape` if specified,
         otherwise the shape of the moving image.
+
     Notes
     ------
     The default value for the affine transformation is "-1" to handle the case
@@ -763,25 +766,32 @@ def plot_cv_tri():
 
 def plot_learning_curves(estimators, X_sets, y, train_sizes, labels=None,
                          errors=True, **kwargs):
-    ''' Generate multi-panel plot displaying learning curves for multiple
-    predictor sets and/or estimators.
+    '''
+    Generate multi-panel plot displaying learning curves for multiple predictor
+    sets and/or estimators.
 
-    Args:
-        estimators (Estimator, list): A scikit-learn Estimator or list of
-            estimators. If a list is provided, it must have the same number of
-            elements as X_sets.
-        X_sets (NDArray-like, list): An NDArray or similar object, or list. If
-            a list is passed, it must have the same number of elements as
-            estimators.
-        y (NDArray): a 1-D numpy array (or pandas Series) representing the
-            outcome variable to predict.
-        train_sizes (list): List of ints providing the sample sizes at which to
-            evaluate the estimator.
-        labels (list): Optional list of labels for the panels. Must have the
-            same number of elements as X_sets.
-        errors (bool): If True, plots error bars representing 1 StDev.
-        kwargs (dict): Optional keyword arguments passed on to sklearn's
-            `learning_curve` utility.
+    Parameters
+    ----------
+    estimators : list,
+        A scikit-learn Estimator or list of estimators. If a list is provided,
+        it must have the same number of elements as X_sets.
+    X_sets : list,
+        An NDArray or similar object, or list. If a list is passed, it must
+        have the same number of elements as estimators.
+    y : ndarray
+        A 1-D numpy array (or pandas Series) representing the outcome variable
+        to predict.
+    train_sizes : list
+        List of ints providing the sample sizes at which to evaluate the
+        estimator.
+    labels : list, optional.
+        List of labels for the panels. Must have the same number of elements as
+        X_sets.
+    errors : bool, optional.
+         If True, plots error bars representing 1 StDev. Default: True.
+    kwargs : dict, optional
+        Optional keyword arguments passed on to sklearn's `learning_curve`
+        utility.
     '''
     # Set up figure
     n_col = len(X_sets)
